@@ -67,10 +67,10 @@ class S3FullScan(FileRegistry):
 
         # If file registry is found
         if not dataframe:
-            LOGGER.info("No registry found create one at %s", self.file_registry_path)
+            LOGGER.info(f"No registry found create one at {self.file_registry_path}")
             self._create_file_registry()
         else:
-            LOGGER.info("File registry found at %s", self.file_registry_path)
+            LOGGER.info(f"File registry found at {self.file_registry_path}")
 
         self.delta_table = DeltaTable(self.file_registry_path, self.spark)
 
@@ -119,7 +119,8 @@ class S3FullScan(FileRegistry):
     def _create_hive_table(self, file_registry_path: str):
         hive = HiveTable(self.spark, self.hive_database_name, self.hive_table_name)
         hive.create(
-            file_registry_path, db_schema=self.db_schema,
+            file_registry_path,
+            db_schema=self.db_schema,
         )
 
     def _rows_to_dataframe(self, rows: List[FileRegistryRow]) -> DataFrame:
